@@ -77,6 +77,21 @@ func TestFollowSymlinks(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestShowAnnexedSize(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", ShowAnnexedSize: true},
+		[]string{"test_dir"},
+		false,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Contains(t, out, "nested")
+	assert.Nil(t, err)
+}
+
 func TestAnalyzePathProfiling(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -99,7 +114,7 @@ func TestAnalyzePathWithIgnoring(t *testing.T) {
 	out, err := runApp(
 		&Flags{
 			LogFile:           "/dev/null",
-			IgnoreDirPatterns: []string{"/[abc]+"},
+			IgnoreDirPatterns: []string{"/(abc)+"},
 			NoHidden:          true,
 		},
 		[]string{"test_dir"},
@@ -209,6 +224,21 @@ func TestGuiNoDelete(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestGuiNoSpawnShell(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", NoSpawnShell: true},
+		[]string{"test_dir"},
+		true,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Empty(t, out)
+	assert.Nil(t, err)
+}
+
 func TestGuiDeleteInParallel(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -377,7 +407,7 @@ func TestReadWrongAnalysisFromFile(t *testing.T) {
 	)
 
 	assert.Empty(t, out)
-	assert.Contains(t, err.Error(), "Array of maps not found")
+	assert.Contains(t, err.Error(), "array of maps not found")
 }
 
 func TestWrongCombinationOfPrefixes(t *testing.T) {
@@ -533,7 +563,7 @@ func TestMaxCoresLowEdge(t *testing.T) {
 }
 
 // nolint: unparam // Why: it's used in linux tests
-func runApp(flags *Flags, args []string, istty bool, getter device.DevicesInfoGetter) (string, error) {
+func runApp(flags *Flags, args []string, istty bool, getter device.DevicesInfoGetter) (output string, err error) {
 	buff := bytes.NewBufferString("")
 
 	app := App{
@@ -545,7 +575,7 @@ func runApp(flags *Flags, args []string, istty bool, getter device.DevicesInfoGe
 		Getter:      getter,
 		PathChecker: testdir.MockedPathChecker,
 	}
-	err := app.Run()
+	err = app.Run()
 
 	return strings.TrimSpace(buff.String()), err
 }
