@@ -39,7 +39,7 @@ func TestRemoveFileParallel(t *testing.T) {
 	dir.Files = fs.Files{subdir}
 	subdir.Files = fs.Files{file}
 
-	err := RemoveItemFromDirParallel(subdir, file)
+	err := ItemFromDirParallel(subdir, file)
 	assert.Nil(t, err)
 
 	assert.Equal(t, 0, len(subdir.Files))
@@ -57,13 +57,13 @@ func TestRemoveDirParallel(t *testing.T) {
 
 	analyzer := analyze.CreateAnalyzer()
 	dir := analyzer.AnalyzeDir(
-		"test_dir", func(_, _ string) bool { return false }, false,
+		"test_dir", func(_, _ string) bool { return false }, func(_ string) bool { return false },
 	).(*analyze.Dir)
 	analyzer.GetDone().Wait()
 	dir.UpdateStats(make(fs.HardLinkedItems))
 
 	subdir := dir.Files[0].(*analyze.Dir)
 
-	err := RemoveItemFromDirParallel(dir, subdir)
+	err := ItemFromDirParallel(dir, subdir)
 	assert.Nil(t, err)
 }
