@@ -12,6 +12,9 @@ import (
 	"strings"
 	"time"
 
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
+
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
 
@@ -24,7 +27,7 @@ import (
 
 const (
 	defaultLinesCount = 500
-	linesTreshold     = 20
+	linesThreshold    = 20
 
 	actionEmpty  = "empty"
 	actionDelete = "delete"
@@ -68,11 +71,12 @@ func (ui *UI) AnalyzePath(path string, parentDir fs.Item) error {
 
 	go func() {
 		defer debug.FreeOSMemory()
-		currentDir := ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc(), ui.ConstGC)
+		currentDir := ui.Analyzer.AnalyzeDir(path, ui.CreateIgnoreFunc(), ui.CreateFileTypeFilter())
 
 		if parentDir != nil {
 			currentDir.SetParent(parentDir)
-			parentDir.SetFiles(parentDir.GetFiles().RemoveByName(currentDir.GetName()))
+			// Remove old entry with the same name and add new one
+			parentDir.RemoveFileByName(currentDir.GetName())
 			parentDir.AddFile(currentDir)
 		} else {
 			ui.topDirPath = path
@@ -191,8 +195,7 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 		acting = actingDelete
 	}
 	modal := tview.NewModal().SetText(
-		// nolint: staticcheck // Why: fixed string
-		strings.Title(acting) +
+		cases.Title(language.English).String(acting) +
 			" " +
 			tview.Escape(selectedItem.GetName()) +
 			"...",
@@ -202,8 +205,8 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 	var currentDir fs.Item
 	var deleteItems []fs.Item
 	if shouldEmpty && selectedItem.IsDir() {
-		currentDir = selectedItem.(*analyze.Dir)
-		for _, file := range currentDir.GetFiles() {
+		currentDir = selectedItem
+		for file := range currentDir.GetFiles(fs.SortBySize, fs.SortDesc) {
 			deleteItems = append(deleteItems, file)
 		}
 	} else {
@@ -396,12 +399,20 @@ func (ui *UI) exportAnalysis() {
 		}
 
 		if _, err = buff.Write([]byte("]\n")); err != nil {
-			ui.showErrFromGo("Error writting to buffer", err)
+			ui.showErrFromGo("Error writing to buffer", err)
 			return
 		}
 		if _, err = buff.WriteTo(file); err != nil {
-			ui.showErrFromGo("Error writting to file", err)
+			ui.showErrFromGo("Error writing to file", err)
 			return
 		}
 	}()
 }
+
+func (ui *UI) isInArchive() bool {
+	if ui.currentDir == nil {
+		return false
+	}
+	_, ok := ui.currentDir.(*analyze.ZipDir)
+	return ok
+}
