@@ -29,7 +29,7 @@ func TestFooter(t *testing.T) {
 	app, simScreen := testapp.CreateTestAppWithSimScreen(15, 15)
 	defer simScreen.Fini()
 
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	dir := &analyze.Dir{
 		File: &analyze.File{
@@ -58,7 +58,7 @@ func TestFooter(t *testing.T) {
 
 	b, _, _ := simScreen.GetContents()
 
-	printScreen(simScreen)
+	// printScreen(simScreen)
 
 	text := []byte(" Total disk    usage: 4.0 KiB Apparent size: 2 B Items: 1")
 	for i, r := range b {
@@ -74,7 +74,7 @@ func TestUpdateProgress(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false)
 	done := ui.Analyzer.GetDone()
 	done.Broadcast()
 	ui.updateProgress()
@@ -85,7 +85,7 @@ func TestHelp(t *testing.T) {
 	app, simScreen := testapp.CreateTestAppWithSimScreen(50, 50)
 	defer simScreen.Fini()
 
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false)
 	ui.showHelp()
 
 	assert.True(t, ui.pages.HasPage("help"))
@@ -109,7 +109,7 @@ func TestHelpBw(t *testing.T) {
 	app, simScreen := testapp.CreateTestAppWithSimScreen(50, 50)
 	defer simScreen.Fini()
 
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 	ui.showHelp()
 	ui.help.Draw(simScreen)
 	simScreen.Show()
@@ -131,7 +131,7 @@ func TestAppRun(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	err := ui.StartUILoop()
 
@@ -143,7 +143,7 @@ func TestAppRunWithErr(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	err := ui.StartUILoop()
 
@@ -167,7 +167,7 @@ func TestRescanDir(t *testing.T) {
 	simScreen := testapp.CreateSimScreen()
 	defer simScreen.Fini()
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 	ui.done = make(chan struct{})
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.currentDir = currentDir
@@ -216,7 +216,7 @@ func TestSelectedWithoutCurrentDir(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false)
 
 	ui.fileItemSelected(1, 0)
 
@@ -230,7 +230,7 @@ func TestBeforeDraw(t *testing.T) {
 	assert.Nil(t, err)
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, screen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, screen, &bytes.Buffer{}, false, true, false, false)
 
 	for _, f := range ui.app.(*testapp.MockedApp).BeforeDraws {
 		assert.False(t, f(screen))
@@ -242,7 +242,7 @@ func TestIgnorePaths(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.SetIgnoreDirPaths([]string{"/aaa", "/bbb"})
 
@@ -676,7 +676,7 @@ func TestShowErr(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false)
 
 	ui.showErr("Something went wrong", errors.New("error"))
 
@@ -688,7 +688,7 @@ func TestShowErrBW(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.showErr("Something went wrong", errors.New("error"))
 
@@ -710,7 +710,7 @@ func TestSetStyles(t *testing.T) {
 	})
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false, opts...)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, opts...)
 
 	ui.SetSelectedBackgroundColor(tcell.ColorRed)
 	ui.SetSelectedTextColor(tcell.ColorRed)
@@ -739,7 +739,7 @@ func TestSetCurrentItemNameMaxLen(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.SetCurrentItemNameMaxLen(5)
 
@@ -751,7 +751,7 @@ func TestUseOldSizeBar(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.UseOldSizeBar()
 
@@ -763,7 +763,7 @@ func TestSetShowItemCount(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.SetShowItemCount()
 
@@ -775,7 +775,7 @@ func TestSetShowMTime(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.SetShowMTime()
 
@@ -787,14 +787,26 @@ func TestNoDelete(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
 
 	ui.SetNoDelete()
 
 	assert.Equal(t, ui.noDelete, true)
 }
 
-// nolint: deadcode,unused // Why: for debugging
+func TestNoSpawnShell(t *testing.T) {
+	simScreen := testapp.CreateSimScreen()
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false)
+
+	ui.SetNoSpawnShell()
+
+	assert.Equal(t, ui.noSpawnShell, true)
+}
+
+// nolint: unused // Why: for debugging
 func printScreen(simScreen tcell.SimulationScreen) {
 	b, _, _ := simScreen.GetContents()
 
@@ -829,7 +841,7 @@ func getAnalyzedPathMockedApp(t *testing.T, useColors, apparentSize, mockedAnaly
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, useColors, apparentSize, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, useColors, apparentSize, false, false)
 
 	if mockedAnalyzer {
 		ui.Analyzer = &testanalyze.MockedAnalyzer{}
@@ -848,3 +860,148 @@ func getAnalyzedPathMockedApp(t *testing.T, useColors, apparentSize, mockedAnaly
 
 	return ui
 }
+
+func TestConfirmDeletionSelectedButtonOrder(t *testing.T) {
+	ui := getAnalyzedPathMockedApp(t, true, true, true)
+
+	ui.table.Select(1, 0)
+	ui.confirmDeletionSelected(false)
+
+	// Verify confirmation page is created
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestConfirmDeletionSelectedSafeDefault(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	ui := getAnalyzedPathMockedApp(t, false, true, false)
+	ui.done = make(chan struct{})
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+	ui.table.Select(0, 0)
+
+	// Create confirmation dialog
+	ui.confirmDeletionSelected(false)
+
+	// Verify that the confirmation dialog exists with safer defaults
+	assert.DirExists(t, "test_dir/nested")
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestConfirmDeletionButtonIndexMapping(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	ui := getAnalyzedPathMockedApp(t, false, true, false)
+	ui.done = make(chan struct{})
+	ui.askBeforeDelete = false // Skip confirmation for direct testing
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+	ui.table.Select(0, 0)
+
+	// Test that deletion still works when explicitly called
+	ui.deleteSelected(false)
+
+	<-ui.done
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.NoDirExists(t, "test_dir/nested")
+}
+
+func TestConfirmEmptySelectedSafeDefault(t *testing.T) {
+	ui := getAnalyzedPathMockedApp(t, true, true, true)
+
+	ui.table.Select(1, 0)
+	ui.confirmDeletionSelected(true)
+
+	// Verify empty confirmation dialog is created safely
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestConfirmDeletionMarkedSafeDefault(t *testing.T) {
+	ui := getAnalyzedPathMockedApp(t, true, true, true)
+
+	ui.table.Select(1, 0)
+	ui.markedRows[1] = struct{}{}
+	ui.confirmDeletionMarked(false)
+
+	// Verify marked deletion confirmation dialog is created safely
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestConfirmEmptyMarkedSafeDefault(t *testing.T) {
+	ui := getAnalyzedPathMockedApp(t, false, true, true)
+
+	ui.table.Select(1, 0)
+	ui.markedRows[1] = struct{}{}
+	ui.confirmDeletionMarked(true)
+
+	// Verify marked empty confirmation dialog is created safely
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestSaferConfirmationPreventDataLoss(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	ui := getAnalyzedPathMockedApp(t, false, true, false)
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+	ui.table.Select(0, 0)
+
+	// Test that creating confirmation dialog doesn't accidentally trigger deletion
+	ui.confirmDeletionSelected(false)
+	ui.confirmDeletionSelected(true) // empty
+
+	// Directory should still exist - no accidental deletion
+	assert.DirExists(t, "test_dir/nested")
+	assert.True(t, ui.pages.HasPage("confirm"))
+}
+
+func TestConfirmDeletionSelectedCase1(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	ui := getAnalyzedPathMockedApp(t, false, true, false)
+	ui.done = make(chan struct{})
+
+	assert.Equal(t, 1, ui.table.GetRowCount())
+	ui.table.Select(0, 0)
+
+	// Test case 1 branch (yes button at index 1) by directly calling deleteSelected
+	ui.deleteSelected(false)
+
+	<-ui.done
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.NoDirExists(t, "test_dir/nested")
+}
+
+func TestConfirmDeletionMarkedCase1(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	ui := getAnalyzedPathMockedApp(t, false, true, false)
+	ui.done = make(chan struct{})
+
+	ui.fileItemSelected(0, 0)     // nested
+	ui.markedRows[1] = struct{}{} // subnested
+
+	// Test case 1 branch (yes button at index 1) by directly calling deleteMarked
+	ui.deleteMarked(false)
+
+	<-ui.done
+
+	for _, f := range ui.app.(*testapp.MockedApp).GetUpdateDraws() {
+		f()
+	}
+
+	assert.NoDirExists(t, "test_dir/nested/subnested")
+}
